/**
 * name: @oplayer/torrent
 * version: v1.2.25-beta.2
 * description: Torrent plugin for oplayer.
 * author: shiyiya
 * homepage: https://github.com/shiyiya/oplayer
 */
import { loadSDK } from "@oplayer/core";
const _TorrentPlugin = class _TorrentPlugin {
  constructor(options) {
    this.options = options;
    this.key = "torrent";
    this.name = "oplayer-plugin-torrent";
    this.version = "1.2.25-beta.2";
  }
  apply(player) {
    this.player = player;
    return this;
  }
  async load(_ref, source) {
    let $video = _ref.$video;
    const _this$options = this.options, _this$options$config = _this$options.config, config = _this$options$config === void 0 ? {} : _this$options$config, _this$options$matcher = _this$options.matcher, matcher = _this$options$matcher === void 0 ? _TorrentPlugin.defaultMatcher : _this$options$matcher, library = _this$options.library;
    if (!matcher(source))
      return false;
    if (!_TorrentPlugin.library) {
      _TorrentPlugin.library = globalThis.WebTorrent || (library ? await loadSDK(library, "WebTorrent") : (await import("webtorrent/webtorrent.min.js")).default);
    }
    const webtorrent = _TorrentPlugin.library;
    if (!webtorrent.WEBRTC_SUPPORT)
      return false;
    const instance = this.instance = new webtorrent(config);
    const medias = [];
    instance.add(source.src, (torrent) => {
      var _a;
      torrent.files.forEach((file) => {
        if (file.name.endsWith(".mp4")) {
          medias.push(file);
        } else if (file.name.startsWith("poster")) {
          file.getBlobURL((err, url) => {
            if (err || !url)
              return;
            $video.poster = url;
          });
        }
      });
      if (!medias.length)
        throw new Error("media not found");
      this.player.on("loadedmetadata", (e) => {
        if (this.instance) {
          setTimeout(() => {
            this.player.emit("canplay", e);
          });
        }
      });
      medias[0].renderTo($video, {
        controls: false
      });
      (_a = this.player.context.ui) == null ? void 0 : _a.menu.register({
        name: "Torrent",
        position: "top",
        children: medias.map((media, i) => ({
          name: media.name,
          default: i == 0,
          value: media
        })),
        onChange(_ref2, elm) {
          let value = _ref2.value, name = _ref2.name;
          elm.innerText = name;
          value.renderTo($video, {
            controls: false
          });
        }
      });
    });
    return this;
  }
  async unload() {
    if (this.instance)
      await this.instance.destroy();
  }
  async destroy() {
    await this.unload();
  }
};
_TorrentPlugin.defaultMatcher = (source) => /magnet:?[^\"]+/.test(source.src) || /.*\.torrent/.test(source.src);
let TorrentPlugin = _TorrentPlugin;
function create() {
  let options = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
  return new TorrentPlugin(options);
}
export {
  create as default
};
